# Vorteex: Library and CLI tool for interacting with [vorteex.io](https://vorteex.io)

Vorteex aims to be the golden standard for navigating today's complex Cybersecurity landscape, it's a tool for researchers,
investigators and advanced hobbyists who wish to obtain, visualize and make sense of data.


## Installation

```
$ pip install vorteex
```

## Get started (CLI)

```
$ vorteex --help
usage: vorteex [-h] [--json] {auth,query,configure} ...

Vorteex CLI tool

positional arguments:
  {auth,query,configure}
    auth                Associate to your Vorteex account
    query               Make a query
    configure           Configure API keys

optional arguments:
  -h, --help            show this help message and exit
  --json                Output results in JSON
```

## Get started (library)

Coming soon...


## Documentation

You can check out the docs at [https://vorteex.readthedocs.org](https://vorteex.readthedocs.org)

